@@ -14,5 +14,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # --------------------------------------------------------------------------
-
-__version__ = '0.0.5'
\ No newline at end of file
+SDK_MAJOR = '0'
+SDK_MINOR = '0'
+SDK_PATCH = '6'
+_locked = False
+__version__ = '0.0.6'
\ No newline at end of file
